==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/entity/PackedSnowballEntity.java <==
package com.github.thedeathlycow.frostiful.entity;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.config.group.CombatConfigGroup;
import com.github.thedeathlycow.frostiful.registry.FEntityTypes;
import com.github.thedeathlycow.frostiful.registry.FItems;
import com.github.thedeathlycow.thermoo.api.temperature.HeatingModes;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2392;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_3483;
import net.minecraft.class_3857;
import net.minecraft.class_3966;
import net.minecraft.class_6024;

public class PackedSnowballEntity extends class_3857 {

    public PackedSnowballEntity(class_1299<? extends PackedSnowballEntity> entityType, class_1937 world) {
        super(entityType, world);
    }

    public PackedSnowballEntity(class_1937 world, class_1309 owner) {
        super(FEntityTypes.PACKED_SNOWBALL, owner, world);
    }

    public PackedSnowballEntity(class_1937 world, double x, double y, double z) {
        super(FEntityTypes.PACKED_SNOWBALL, x, y, z, world);
    }

    @Override
    protected class_1792 method_16942() {
        return FItems.PACKED_SNOWBALL;
    }

    @Override
    public void method_5711(byte status) {
        if (status == class_6024.field_30028) {
            class_2394 particleEffect = this.getParticleEffect();
            for (int i = 0; i < 8; i++) {
                this.method_37908().method_8406(
                        particleEffect,
                        this.method_23317(), this.method_23318(), this.method_23321(),
                        0.0, 0.0, 0.0
                );
            }
        }
    }

    @Override
    protected void method_7454(class_3966 entityHitResult) {
        super.method_7454(entityHitResult);
        class_1297 target = entityHitResult.method_17782();

        CombatConfigGroup config = Frostiful.getConfig().combatConfig;

        float damage = target.method_5864().method_20210(class_3483.field_29826)
                ? config.getPackedSnowballVulnerableTypesDamage()
                : config.getPackedSnowballDamage();

        target.method_5643(this.method_48923().method_48811(this, this.method_24921()), damage);

        if (target instanceof class_1309 livingTarget) {
            livingTarget.thermoo$addTemperature(
                    -config.getPackedSnowballFreezeAmount(),
                    HeatingModes.ACTIVE
            );
        }
    }

    @Override
    protected void method_7488(class_239 hitResult) {
        super.method_7488(hitResult);
        class_1937 world = method_37908();
        if (!world.field_9236) {
            world.method_8421(this, class_6024.field_30028);
            this.method_31472();
        }
    }

    private class_2394 getParticleEffect() {
        class_1799 itemStack = this.method_7495();
        return itemStack.method_7960()
                ? class_2398.field_11230
                : new class_2392(class_2398.field_11218, itemStack);
    }

}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/entity/PackedSnowballEntity.java <==
package com.github.thedeathlycow.frostiful.entity;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.config.group.CombatConfigGroup;
import com.github.thedeathlycow.frostiful.registry.FEntityTypes;
import com.github.thedeathlycow.frostiful.registry.FItems;
import com.github.thedeathlycow.thermoo.api.temperature.HeatingModes;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2392;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_3483;
import net.minecraft.class_3857;
import net.minecraft.class_3966;
import net.minecraft.class_6024;

public class PackedSnowballEntity extends class_3857 {

    public PackedSnowballEntity(class_1299<? extends PackedSnowballEntity> entityType, class_1937 world) {
        super(entityType, world);
    }

    public PackedSnowballEntity(class_1937 world, class_1309 owner, class_1799 stack) {
        super(FEntityTypes.PACKED_SNOWBALL, owner, world, stack);
    }

    public PackedSnowballEntity(class_1937 world, double x, double y, double z, class_1799 stack) {
        super(FEntityTypes.PACKED_SNOWBALL, x, y, z, world, stack);
    }

    @Override
    protected class_1792 method_16942() {
        return FItems.PACKED_SNOWBALL;
    }

    @Override
    public void method_5711(byte status) {
        if (status == class_6024.field_30028) {
            class_2394 particleEffect = this.getParticleEffect();
            for (int i = 0; i < 8; i++) {
                this.method_37908().method_8406(
                        particleEffect,
                        this.method_23317(), this.method_23318(), this.method_23321(),
                        0.0, 0.0, 0.0
                );
            }
        }
    }

    @Override
    protected void method_7454(class_3966 entityHitResult) {
        super.method_7454(entityHitResult);
        class_1297 target = entityHitResult.method_17782();

        CombatConfigGroup config = Frostiful.getConfig().combatConfig;

        float damage = target.method_5864().method_20210(class_3483.field_29826)
                ? config.getPackedSnowballVulnerableTypesDamage()
                : config.getPackedSnowballDamage();

        target.method_64419(this.method_48923().method_48811(this, this.method_24921()), damage);

        if (target instanceof class_1309 livingTarget) {
            livingTarget.thermoo$addTemperature(
                    -config.getPackedSnowballFreezeAmount(),
                    HeatingModes.ACTIVE
            );
        }
    }

    @Override
    protected void method_7488(class_239 hitResult) {
        super.method_7488(hitResult);
        class_1937 world = method_37908();
        if (!world.field_9236) {
            world.method_8421(this, class_6024.field_30028);
            this.method_31472();
        }
    }

    private class_2394 getParticleEffect() {
        class_1799 itemStack = this.method_7495();
        return itemStack.method_7960()
                ? class_2398.field_11230
                : new class_2392(class_2398.field_11218, itemStack);
    }

}
